#!/bin/bash

# 获取当前用户的 UID
current_uid=$(id -u)
# 获取脚本名（包含参数，去掉路径）
process_name=$(basename "$0")
script_name="${process_name} $@"
current_dir=$(pwd)

# 判断dbus-send命令是否存在
if [ ! command -v dbus-send &> /dev/null ]; then
    echo "dbus-send command not found. Please install D-Bus utilities."
    exit 1
fi

if [ "$process_name" == "xdg-open" ] && [ "$current_uid" -ne 0 ]; then
    dbus-send --session \
    --print-reply \
    --dest=org.kaiming.proxy \
    --type=method_call \
    /org/kaiming/proxy \
    org.kaiming.proxy.session.xdgOpen \
    string:$1 \
    string:"$current_dir" >/dev/null
    exit 0
fi


if [ "$current_uid" -eq 0 ]; then
    # 通过 D-Bus 发送 system 级请求
    dbus-send --system \
        --reply-timeout=100000000000 \
        --print-reply \
        --dest=org.kaiming.proxy \
        /org/kaiming/proxy \
        org.kaiming.proxy.system.startBinaryAsUser \
        int32:"$current_uid" \
        string:"$script_name" \
        string:"$current_dir"
else
    # 通过 D-Bus 发送 session 级请求
    dbus-send --session \
        --reply-timeout=100000000000 \
        --print-reply \
        --dest=org.kaiming.proxy \
        /org/kaiming/proxy \
        org.kaiming.proxy.session.startBinaryAsUser \
        int32:"$current_uid" \
        string:"$script_name" \
        string:"$current_dir"
fi